#
# Configure paths and flags for the SimCRS library.
# Denis Arnaud <denis_arnaud at users dot sourceforge dot net>, July 2008
#
# Note: the SIMCRS library depends upon BOOST to build.
# Your configure.ac must therefore define appropriately the BOOST
# variables (i.e., BOOST_CFLAGS, BOOST_LIBS, BOOST_DATE_TIME_LIB).
#
# Variables set by this macro:
#  * SIMCRS_VERSION
#  * SIMCRS_CFLAGS
#  * SIMCRS_LIBS
#  * SIMCRS_SAMPLE_DIR
#

AC_DEFUN([AM_PATH_SIMCRS],
[
AC_LANG_SAVE
AC_LANG([C++])

##
AC_ARG_WITH(simcrs,
	[ --with-simcrs=PFX Prefix where SimCRS is installed (optional) ],
	    simcrs_dir="$withval",
	    simcrs_dir="")

  if test "x${SIMCRS_CONFIG+set}" != xset ; then
     if test "x$simcrs_dir" != x ; then
         SIMCRS_CONFIG="$simcrs_dir/bin/simcrs-config"
     fi
  fi

  AC_PATH_PROG(SIMCRS_CONFIG, simcrs-config, no)

  ## Check whether Boost flags and libraries are defined
  # General Boost compilation flags
  AC_MSG_CHECKING(for BOOST_CFLAGS environment variable)
  if test x"${BOOST_CFLAGS}" = x; then
	AC_MSG_RESULT([Warning: SimCRS needs Boost, and the BOOST_CFLAGS environment variable does not appear to be set. It may not be a problem, though, if your Unix distribution is standard, that is, if Boost is installed in /usr. Otherwise, the SimCRS will fail to compile.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_CFLAGS})])
  fi

  # Boost Date-Time library
  AC_MSG_CHECKING(for BOOST_DATE_TIME_LIB environment variable)
  if test x"${BOOST_DATE_TIME_LIB}" = x; then
	AC_MSG_RESULT([Warning: SimCRS needs the Boost Date-Time library, and the BOOST_DATE_TIME_LIB environment variable does not appears to be set. The SimCRS may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_DATE_TIME_LIB})])
  fi

  # Boost Program Options library
  AC_MSG_CHECKING(for BOOST_PROGRAM_OPTIONS_LIB environment variable)
  if test x"${BOOST_PROGRAM_OPTIONS_LIB}" = x; then
	AC_MSG_RESULT([Warning: SimCRS needs the Boost Program Options library, and the BOOST_PROGRAM_OPTIONS_LIB environment variable does not appears to be set. The SimCRS may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_PROGRAM_OPTIONS_LIB})])
  fi

  # Boost File System library
  AC_MSG_CHECKING(for BOOST_FILESYSTEM_LIB environment variable)
  if test x"${BOOST_FILESYSTEM_LIB}" = x; then
	AC_MSG_RESULT([Warning: SimCRS needs the Boost Date-Time library, and the BOOST_FILESYSTEM_LIB environment variable does not appears to be set. The SimCRS may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_FILESYSTEM_LIB})])
  fi

  ## SimCRS version
  min_simcrs_version=ifelse([$1], ,0.1.0,$1)
  AC_MSG_CHECKING(for SimCRS - version >= $min_simcrs_version)
  no_simcrs=""
  if test "${SIMCRS_CONFIG}" = "no" ; then
     no_simcrs=yes
     AC_MSG_RESULT([no])
  else
     SIMCRS_VERSION=`${SIMCRS_CONFIG} --version`
     SIMCRS_CFLAGS=`${SIMCRS_CONFIG} --cflags`
     SIMCRS_CFLAGS="${BOOST_CFLAGS} ${SIMCRS_CFLAGS}"
     SIMCRS_LIBS=`${SIMCRS_CONFIG} --libs`
     SIMCRS_LIBS="${BOOST_LIBS} ${BOOST_DATE_TIME_LIB} ${SIMCRS_LIBS}"
     SIMCRS_SAMPLE_DIR=`${SIMCRS_CONFIG} --sampledir`

     AC_SUBST([SIMCRS_VERSION])
     AC_SUBST([SIMCRS_CFLAGS])
     AC_SUBST([SIMCRS_LIBS])
     AC_SUBST([SIMCRS_SAMPLE_DIR])

    simcrs_major_version=`echo ${SIMCRS_VERSION} | sed 's/^\([[0-9]]*\).*/\1/'`
    if test "x${simcrs_major_version}" = "x" ; then
       simcrs_major_version=0
    fi

    simcrs_minor_version=`echo ${SIMCRS_VERSION} | \
						sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\2/'`
    if test "x${simcrs_minor_version}" = "x" ; then
       simcrs_minor_version=0
    fi

    simcrs_micro_version=`echo ${SIMCRS_VERSION} | \
          sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\3/'`
    if test "x${simcrs_micro_version}" = "x" ; then
       simcrs_micro_version=0
    fi

    ## Simple test of compilation and link
    SAVED_CPPFLAGS="${CPPFLAGS}"
    SAVED_LDFLAGS="${LDFLAGS}"
    CPPFLAGS="${CPPFLAGS} ${BOOST_CFLAGS} ${SIMCRS_CFLAGS}"
    LDFLAGS="${LDFLAGS} ${SIMCRS_LIBS}"


    AC_COMPILE_IFELSE(
		[AC_LANG_PROGRAM([[#include <simcrs/SIMCRS_Service.hpp>
				]],
				[[int i=0;]]
		)]
		,

    	[AC_MSG_RESULT([yes (${SIMCRS_VERSION})])],

	[AC_MSG_ERROR([We could not compile a simple SimCRS example. See config.log.])]
    )

    CPPFLAGS="${SAVED_CPPFLAGS}"
    LDFLAGS="${SAVED_LDFLAGS}"

  fi

AC_LANG_RESTORE
])
